==> fwbuilder_4.1.3.orig.tar.gz: fwbuilder-4.1.3/src/unit_tests/compilerLibTest/tests_main.cpp <==
/*

                          Firewall Builder

                 Copyright (C) 2009 NetCitadel, LLC

  Author:  Roman Bovsunivkiy     a2k0001@gmail.com

  $Id: main.cpp 2039 2009-12-05 20:16:44Z a2k $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

#include "common/init.cpp"
#include "interfacePropertiesTest.h"

#include <cppunit/ui/text/TestRunner.h>
#include <cppunit/CompilerOutputter.h>
#include <string>

//int build_num = 0;
//std::string respath;
//QString user_name;

int main(int, char **argv)
{
    init(argv);

    init();

    Resources res(respath + FS_SEPARATOR + "resources.xml");
    // Resources("../../res/resources.xml");


    CppUnit::TextUi::TestRunner runner;
    runner.addTest( interfacePropertiesTest::suite() );
    runner.setOutputter( new CppUnit::CompilerOutputter( &runner.result(),
                                                         std::cerr ) );

    runner.run();
    return 0;
}

==> fwbuilder_5.1.0.orig.tar.gz: fwbuilder-5.1.0.3599/src/unit_tests/compilerLibTest/tests_main.cpp <==
/*

                          Firewall Builder

                 Copyright (C) 2009 NetCitadel, LLC

  Author:  Roman Bovsunivkiy     a2k0001@gmail.com

  $Id: main.cpp 2039 2009-12-05 20:16:44Z a2k $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

#include "common/init.cpp"
#include "interfacePropertiesTest.h"

#include "fwbuilder/Constants.h"

#include <cppunit/ui/text/TestRunner.h>
#include <cppunit/CompilerOutputter.h>
#include <string>

//QString user_name;

int main(int, char **argv)
{
    init(argv);

    init();

    Resources res(Constants::getResourcesFilePath());

    CppUnit::TextUi::TestRunner runner;
    runner.addTest( interfacePropertiesTest::suite() );
    runner.setOutputter( new CppUnit::CompilerOutputter( &runner.result(),
                                                         std::cerr ) );

    runner.run();
    return 0;
}
